@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2000-2010 Jeffrey Stedfast
+ *  Copyright (C) 2000-2009 Jeffrey Stedfast
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -191,26 +191,10 @@ static struct {
 	{ "\"=?ISO-8859-2?Q?TEST?=\" <p@p.org>",
 	  "TEST <p@p.org>",
 	  "TEST <p@p.org>" },
-	{ "sdfasf@wp.pl,c tert@wp.pl,sffdg.rtre@op.pl",
-	  "sdfasf@wp.pl, c, sffdg.rtre@op.pl",
-	  "sdfasf@wp.pl, c, sffdg.rtre@op.pl" },
-};
-
-static struct {
-	const char *input;
-	const char *display;
-	const char *encoded;
-} broken_addrspec[] = {
-	{ "\"Biznes=?ISO-8859-2?Q?_?=INTERIA.PL\"=?ISO-8859-2?Q?_?=<biuletyny@firma.interia.pl>",
-	  "\"Biznes INTERIA.PL \" <biuletyny@firma.interia.pl>",
-	  "\"Biznes INTERIA.PL\" <biuletyny@firma.interia.pl>", },
-	{ "=?utf-8?Q?{#D=C3=A8=C3=A9=C2=A3=C3=A5=C3=BD_M$=C3=A1=C3?= =?utf-8?Q?=AD.=C3=A7=C3=B8m@#}?= <user@domain.com>",
-	  "\"{#Dèé£åý M$áí.çøm@#}\" <user@domain.com>",
-	  "=?iso-8859-1?b?eyNE6Omj5f0gTSTh7S7n+G1AI30=?= <user@domain.com>" },
 };
 
 static void
-test_addrspec (gboolean test_broken)
+test_addrspec (void)
 {
 	InternetAddressList *addrlist;
 	char *str;
@@ -243,36 +227,6 @@ test_addrspec (gboolean test_broken)
 		if (addrlist)
 			g_object_unref (addrlist);
 	}
-	
-	if (test_broken) {
-		for (i = 0; i < G_N_ELEMENTS (broken_addrspec); i++) {
-			addrlist = NULL;
-			str = NULL;
-			
-			testsuite_check ("broken_addrspec[%u]", i);
-			try {
-				if (!(addrlist = internet_address_list_parse_string (broken_addrspec[i].input)))
-					throw (exception_new ("could not parse addr-spec"));
-				
-				str = internet_address_list_to_string (addrlist, FALSE);
-				if (strcmp (broken_addrspec[i].display, str) != 0)
-					throw (exception_new ("display addr-spec %s does not match: %s", broken_addrspec[i].display, str));
-				g_free (str);
-				
-				str = internet_address_list_to_string (addrlist, TRUE);
-				if (strcmp (broken_addrspec[i].encoded, str) != 0)
-					throw (exception_new ("encoded addr-spec %s does not match: %s", broken_addrspec[i].encoded, str));
-				
-				testsuite_check_passed ();
-			} catch (ex) {
-				testsuite_check_failed ("broken_addrspec[%u]: %s", i, ex->message);
-			} finally;
-			
-			g_free (str);
-			if (addrlist)
-				g_object_unref (addrlist);
-		}
-	}
 }
 
 
@@ -596,7 +550,7 @@ int main (int argc, char **argv)
 	testsuite_init (argc, argv);
 	
 	testsuite_start ("addr-spec parser");
-	test_addrspec (FALSE);
+	test_addrspec ();
 	testsuite_end ();
 	
 	testsuite_start ("date parser");
@@ -619,7 +573,6 @@ int main (int argc, char **argv)
 	
 	g_mime_init (GMIME_ENABLE_RFC2047_WORKAROUNDS);
 	testsuite_start ("broken rfc2047 encoding/decoding");
-	test_addrspec (TRUE);
 	test_rfc2047 (TRUE);
 	testsuite_end ();
 	g_mime_shutdown ();
